@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 from functools import wraps
-
+from flask import request
 from pydantic import ValidationError
 
 __author__ = "Ahmed Nafies Okasha Mohamed <ahmed.nafies@gmail.com>"
 __copyright__ = "Copyright 2020, Ahmed Nafies Okasha Mohamed"
 __license__ = "MIT"
-__version__ = "0.0.1"
+__version__ = "0.1.0"
 
 
 BODY_METHODS = ["POST", "PUT", "PATCH"]
@@ -21,7 +21,7 @@ class InvalidOperation(Error):
     pass
 
 
-def validate(request, query, body):
+def validate(query, body):
 
     payload = None
     query_params = None
@@ -31,13 +31,11 @@ def validate(request, query, body):
             f"Http method '{request.method}' does not contain a payload,"
             "yet a Pyndatic model for body was suppied"
         )
-
     if body:
         payload = body(**request.json).dict()
 
     if query:
         params = request.args
-        params = {k: v[0] for k, v in params.items()}
         query_params = query(**params).dict()
 
     return dict(payload=payload, query=query_params)
@@ -46,13 +44,13 @@ def validate(request, query, body):
 def webargs(query=None, body=None):
     def decorator(f):
         @wraps(f)
-        def decorated_function(request, *args, **kwargs):
+        def decorated_function(*args, **kwargs):
             try:
-                result = validate(request, query, body)
+                result = validate(query, body)
             except ValidationError as e:
                 return str(e)
             kwargs.update(result)
-            response = f(request, *args, **kwargs)
+            response = f(*args, **kwargs)
             return response
 
         return decorated_function
